/* NiuTrans.Tensor - an open-source tensor library
 * Copyright (C) 2018, Natural Language Processing Lab, Northestern University. 
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * $Created by: XIAO Tong (xiaotong@mail.neu.edu.cn) 2018-07-31
 */

#include "T2TFNN.h"
#include "T2TUtility.h"

namespace transformer
{

/* constructor */
T2TFNN::T2TFNN()
{
    inSize  = -1;
    outSize = -1;
    hSize   = -1;
}

/* deconstructor */
T2TFNN::~T2TFNN()
{
}

/* 
initialize the model 
>> argc - number of arguments
>> argv - list pf pointers to the arguments
>> devID - device id
>> mem - the memory pool
*/
void T2TFNN::InitModel(int argc, const char ** argv, int devID, XMem * mem)
{
    float minmax = 0;

    LoadParamInt(argc, argv, "fnnin", &inSize, 512);
    LoadParamInt(argc, argv, "fnnout", &outSize, 512);
    LoadParamInt(argc, argv, "fnnh", &hSize, 512);
    LoadParamFloat(argc, argv, "fnnminmax", &minmax, 0.08F);

    InitTensor2D(&w1, inSize, hSize, X_FLOAT, devID, mem);
    InitTensor1D(&b1, hSize, X_FLOAT, devID, mem);

    InitTensor2D(&w2, hSize, outSize, X_FLOAT, devID, mem);
    InitTensor1D(&b2, outSize, X_FLOAT, devID, mem);

    w1.SetDataRand(-minmax, minmax);
    b1.SetDataRand(-minmax, minmax);
    w2.SetDataRand(-minmax, minmax);
    b2.SetDataRand(-minmax, minmax);
}


}
